Package: PCRedux
Type: Package
Title: Quantitative Polymerase Chain Reaction (qPCR) Data Mining and
        Machine Learning Toolkit as Described in Burdukiewicz (2022)
        <doi:10.21105/Joss.04407>
Version: 1.2-1
Date: 2025-11-19
Authors@R: c(person("Stefan", "Roediger", 
             email = "stefan.roediger@b-tu.de", 
             comment = c(ORCID = "0000-0002-1441-6512"),
             role = c("aut")),
             person("Michal", "Burdukiewicz", 
             email = "michalburdukiewicz@gmail.com", 
             comment = c(ORCID = "0000-0001-8926-582X"),
             role = c("aut")),
             person("Andrej-Nikolai", "Spiess", 
             email = "draspiess@gmail.com", 
             comment = c(ORCID = "0000-0002-9630-4724"),
             role = c("cre", "aut")),
             person("Konstantin A.", "Blagodatskikh", 
             email = "k.blag@yandex.ru",
             comment = c(ORCID = "0000-0002-8732-0300"),
             role = c("aut")),
             person("Dominik", "Rafacz", 
             email = "dominikrafacz@gmail.com",
             comment = c(ORCID = "0000-0003-0925-1909"),
             role = c("ctb")))
Description: Extracts features from amplification curve data of quantitative 
    Polymerase Chain Reactions (qPCR) according to Pabinger et al. 2014 
    <doi:10.1016/j.bdq.2014.08.002> for machine learning purposes. Helper 
    functions prepare the amplification curve data for processing as functional 
    data (e.g., Hausdorff distance) or enable the plotting of amplification 
    curve classes (negative, ambiguous, positive). The hookreg() and hookregNL() 
    functions of Burdukiewicz et al. (2018) <doi:10.1016/j.bdq.2018.08.001> 
    can be used to predict amplification curves with an hook effect-like 
    curvature. The pcrfit_single() function can be used to extract features 
    from an amplification curve.
License: MIT + file LICENSE
LazyLoad: yes
LazyData: yes
URL: https://CRAN.R-project.org/package=PCRedux
BugReports: https://github.com/PCRuniversum/PCRedux/issues
Depends: R (>= 3.5.0)
Imports: changepoint, chipPCR, ecp, fda.usc, MBmca, pbapply, pracma,
        qpcR, robustbase, segmented, shiny, stats, utils, zoo
Suggests: DT, future, knitr, listenv, RDML, readxl, rmarkdown,
        shinycssloaders, spelling, testthat, xtable
NeedsCompilation: no
VignetteBuilder: knitr
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.1.2
Packaged: 2025-11-19 19:05:32 UTC; User
Repository: CRAN
Date/Publication: 2025-11-19 19:40:06 UTC
Author: Stefan Roediger [aut] (ORCID: <https://orcid.org/0000-0002-1441-6512>),
  Michal Burdukiewicz [aut] (ORCID:
    <https://orcid.org/0000-0001-8926-582X>),
  Andrej-Nikolai Spiess [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-9630-4724>),
  Konstantin A. Blagodatskikh [aut] (ORCID:
    <https://orcid.org/0000-0002-8732-0300>),
  Dominik Rafacz [ctb] (ORCID: <https://orcid.org/0000-0003-0925-1909>)
Maintainer: Andrej-Nikolai Spiess <draspiess@gmail.com>
Built: R 4.6.0; ; 2026-04-30 15:00:48 UTC; unix
