# Generated by roxygen2: do not edit by hand

export(armor)
export(autocorrelation_test)
export(decision_modus)
export(earlyreg)
export(encu)
export(head2tailratio)
export(hookreg)
export(hookregNL)
export(humanrater2)
export(mblrr)
export(pcrfit_single)
export(performeR)
export(qPCR2fdata)
export(run_PCRedux)
export(tReem)
export(winklR)
importFrom(MBmca,diffQ)
importFrom(MBmca,diffQ2)
importFrom(MBmca,mcaPeaks)
importFrom(changepoint,cpt.meanvar)
importFrom(chipPCR,CPP)
importFrom(chipPCR,amptester)
importFrom(chipPCR,bg.max)
importFrom(chipPCR,smoother)
importFrom(ecp,e.agglo)
importFrom(fda.usc,fdata)
importFrom(fda.usc,metric.hausdorff)
importFrom(grDevices,rainbow)
importFrom(graphics,abline)
importFrom(graphics,matplot)
importFrom(graphics,par)
importFrom(pbapply,pblapply)
importFrom(pracma,polyarea)
importFrom(qpcR,AICc)
importFrom(qpcR,LRE)
importFrom(qpcR,efficiency)
importFrom(qpcR,mselect)
importFrom(qpcR,pcrfit)
importFrom(qpcR,sliwin)
importFrom(qpcR,takeoff)
importFrom(robustbase,lmrob)
importFrom(segmented,seg.control)
importFrom(shiny,runApp)
importFrom(stats,coefficients)
importFrom(stats,confint)
importFrom(stats,cor)
importFrom(stats,cor.test)
importFrom(stats,cutree)
importFrom(stats,dist)
importFrom(stats,hclust)
importFrom(stats,lag)
importFrom(stats,lm)
importFrom(stats,mad)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,smooth.spline)
importFrom(stats,wilcox.test)
importFrom(utils,data)
importFrom(utils,head)
importFrom(utils,tail)
importFrom(zoo,as.zoo)
