# PCRedux

Quantitative PCR Machine Learning Toolkit

## Installation

*PCRedux* is available [on CRAN](https://cran.r-project.org/package=PCRedux). However, you 
can install the latest development version of the code using the following code:

```R
library("devtools")
install_github("PCRuniversum/PCRedux")
```

## Manual

The manual is available [online](https://PCRuniversum.github.io/PCRedux/).
